Module git

Module git 

Structs

CommitMetadata
DiffHunk
FileChange
GitRepository
LineChange

Enums

DiffMode
Specifies which working tree changes to show in diff mode
FileStatus
LineChangeType

Functions

init_ignore_patterns
Initialize user-defined ignore patterns (call once at startup)
parse_date
should_exclude_file
Check if a file should be excluded from diff animation