Structs
Enums
- Diff
Mode - Specifies which working tree changes to show in diff mode
- File
Status - Line
Change Type
Functions
- init_
ignore_ patterns - Initialize user-defined ignore patterns (call once at startup)
- parse_
date - should_
exclude_ file - Check if a file should be excluded from diff animation